# HyperFit
A neat python package for fitting N dimensional data with (possibly covariant) errors with an N-1 dimensional plane. Put simply, if you have data with x and y errors and you want the correct method for fitting a straight line, use this package! But it also works for higher dimensions. Examples, tutorials and API here: https://hyperfit.readthedocs.io/en/latest/

Based on the R HyperFit package by Aaron Robotham and Danail Obreschkow. More details on the method can be found here: https://ui.adsabs.harvard.edu/abs/2015PASA...32...33R/abstract. Please cite this paper if you use this package.
